@@ -14,7 +14,8 @@ from djhcup_core.defaults import DATETIME_FORMAT
 
 # set some constants
 ALLOWED_LOG_LEVELS = ['NOTSET', 'DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL']
-
+HACHOIR_DB_ENTRY = 'djhcup'
+DB_DEF = settings.DATABASES[HACHOIR_DB_ENTRY]
 
 # start a logger
 default_logger = logging.getLogger('default')
@@ -233,7 +234,7 @@ class ImportBatch(models.Model):
     
     
     def get_absolute_url(self):
-        return reverse('djhcup_staging.views.batch_detail', kwargs={'batch_id': self.pk})
+        return reverse('djhcup_staging.views.importbatch_detail', kwargs={'batch_id': self.pk})
     
     def __unicode__(self):
         c_items = ImportQueue.objects.filter(batch=self).count()
@@ -545,7 +546,7 @@ class StagingQueue(models.Model):
                                   help_text='DTE_SOURCE, if required.',
                                   null=True, default=None, blank=True)
     aha_input = models.ForeignKey('StagingTable', related_name='aha_input',
-                                  help_text='AHA_SOURCE, if required.',
+                                  help_text='AHALINK_SOURCE, if required.',
                                   null=True, default=None, blank=True)
     
     
@@ -733,17 +734,41 @@ class StagingTable(models.Model):
     
     def __unicode__(self):
         return "StagingTable %d: %s" % (self.pk, self.name)
+    
+    # overwrite method to drop table as well by default
+    def delete(self, drop_table=True, *args, **kwargs):
+        if drop_table:
+            # establish connection directly with psycopg2
+            #DB_BACKEND = DB_DEF['ENGINE'].split('.')[-1]
+            
+            import psycopg2
+            cnxn = psycopg2.connect(
+                host=DB_DEF['HOST'],
+                port=DB_DEF['PORT'],
+                user=DB_DEF['USER'],
+                password=DB_DEF['PASSWORD'],
+                database=DB_DEF['NAME'],
+                )
+            drop_result = pyhcup.db.pg_drop(cnxn, self.name)
+            if drop_result == True:
+                default_logger.info('Dropped table {table} from database'.format(table=self.name))
+            else:
+                default_logger.error('Unable to drop table {table} from database'.format(table=self.name))
+        
+        super(StagingTable, self).delete(*args, **kwargs)
 
 
 class Column(models.Model):
-    #TODO: determine if this is to know what columns are in a raw master table
-    #... or if this is to know what columns are available from each imported state (*I think it's this one)
-    #... or agnostic of import status, what columns are in a discovered loadfile
-    #... or what
-    stg = models.ForeignKey('StagingTable', null=True)
-    name = models.CharField(max_length=200, blank=False,
-                            db_index=True)
+    """Records details on a given column most typically after that column has been imported.
     
+    Required attributes: name, count_notnull, count_null
+    
+    Optional attributes: description, min, max, stddev_samp, stddev_pop, mean
+    """
+    stg = models.ForeignKey('StagingTable', null=True)
+    name = models.CharField(max_length=200, blank=False, db_index=True)
+    description = models.TextField(blank=True, null=True,
+                                   help_text='The description provided by HCUP')
     TYPE_CHOICES = [
         ('VARCHAR', 'Character (string)'),
         ('NUMERIC', 'Numeric (decimal)'),
@@ -756,3 +781,25 @@ class Column(models.Model):
     col_precision = models.IntegerField(blank=True, null=True, help_text='Total sigfigs for numeric fields')
     informat = models.CharField(max_length=100, blank=True, default=None, null=True,
                                 help_text='SAS load informat this column is based on, if applicable')
+    STATUS_CHOICES = [
+        ('UNVERIFIED', 'Verification has not been attempted'),
+        ('UNAVAILABLE_AUTO', 'HCUP summary stats automatically detected as unavailable'),
+        ('UNAVAILABLE_MANUAL', 'HCUP summary stats manually detected as unavailable'),
+        ('VERIFIED_AUTO', 'Verified automatically by comparison with HCUP summary stats'),
+        ('VERIFIED_MANUAL', 'Verified manually by comparison with HCUP summary stats'),
+        ('VERIFIED_OVERRIDE', 'Marked as verified, overriding a known discrepancy with HCUP summary stats'),
+        ('FAILED_AUTO', 'Failed verification automatically by comparison with HCUP summary stats'),
+        ('FAILED_MANUAL', 'Failed verification manually by comparison with HCUP summary stats'),
+        ('FAILED_OVERRIDE', 'Marked as failed, overriding an automatic verification'),
+    ]
+    integrity_status = models.CharField(max_length=100, choices=STATUS_CHOICES, blank=False, default='UNVERIFIED')
+    count_notnull = models.IntegerField(help_text='Count of non-null values.')
+    count_null = models.IntegerField(help_text='Count of null values.')
+    min = models.DecimalField(max_digits=50, decimal_places=6, blank=True, default=None, null=True,)
+    max = models.DecimalField(max_digits=50, decimal_places=6, blank=True, default=None, null=True,)
+    stddev_pop = models.DecimalField(max_digits=50, decimal_places=6, blank=True, default=None, null=True,)
+    stddev_samp = models.DecimalField(max_digits=50, decimal_places=6, blank=True, default=None, null=True,)
+    mean = models.DecimalField(max_digits=50, decimal_places=6, blank=True, default=None, null=True,)
+    
+    def __unicode__(self):
+        return "<Column %s: %s.%s (%s non-null values)>" % (self.pk, self.stg.name, self.name, self.count_notnull)
