@@ -3,6 +3,7 @@ import datetime
 import itertools
 import logging
 import os
+import re
 import sys
 from copy import deepcopy
 
@@ -26,7 +27,7 @@ from django import db as djangodb
 
 # local project and app packages
 from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingQueue, StagingBatch, StagingTable
-from djhcup_staging.utils.misc import dead_batches
+from djhcup_staging.utils.misc import dead_batches, get_pgcnxn
 
 
 # start a logger
@@ -239,17 +240,6 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
     load.log('Begin import',
              level='INFO', logger=logger)
     
-    """
-    TODO: Re-enable if appropriate; omitted for convenience atm
-    cols_saved = load.record_columns()
-    if cols_saved > 0:
-        load.log('Columns saved: %s' % (load),
-                level='INFO', logger=logger)
-    else:
-        load.log('No columns saved',
-                level='WARNING', logger=logger)
-    """
-    
     #schema = destination.schema
     state = load.file.state.abbreviation
     year = load.file.year
@@ -272,14 +262,7 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
     handle = load.file.open()
 
     # establish connection directly with psycopg2
-    import psycopg2
-    cnxn = psycopg2.connect(
-        host=DB_DEF['HOST'],
-        port=DB_DEF['PORT'],
-        user=DB_DEF['USER'],
-        password=DB_DEF['PASSWORD'],
-        database=DB_DEF['NAME'],
-        )
+    cnxn = get_pgcnxn()
     
     # get helper functions
     from pyhcup.db import pg_rawload, pg_staging, pg_shovel, pg_wtl_shovel, pg_drop, pg_dteload
@@ -310,8 +293,7 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
         load.log('StagingTable %s recorded for %s' % (stg_table_name, imported.pk))
         
     else:
-        # use the old style code
-        # let 'er rip
+        # use db loading functions
         meta = load.get_meta()
         
         load.log('Creating raw import table via pg_rawload()',
@@ -350,7 +332,72 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
         
         imported.save()
         
-        load.log('StagingTable %s recorded for %s' % (stg_table_name, imported.pk))
+        load.log('StagingTable %s recorded for %s' % (imported.pk, stg_table_name))
+        
+        # move on to recording summary statistics about imported columns
+        # grab a dbapi2 cursor
+        c = cnxn.cursor()
+
+        # augment meta data for storage in Column object
+        m_aug = pyhcup.meta.augment(meta)
+
+        # v is a series of values in row with dict-style access by label
+        for k, v in m_aug.iterrows():
+            
+            # create Column object with preliminary values
+            col = Column(
+                stg = imported,
+                name = v['field'],
+                description = v['label'],
+                col_type=v['data_type'].upper(),
+                col_scale=v['scale'],
+                col_precision=v['length'],
+                informat=v['informat'],
+                )
+            
+            if v['numeric_or_int']:
+                # numeric types can run descriptive statistics
+                sql = """
+                    SELECT
+                        SUM(CASE WHEN {field} IS NULL THEN 0 ELSE 1 END) AS count_notnull,
+                        SUM(CASE WHEN {field} IS NULL THEN 1 ELSE 0 END) AS count_null,
+                        MIN({field}) AS min,
+                        MAX({field}) AS max,
+                        STDDEV_POP({field}) as stddev_pop,
+                        STDDEV_SAMP({field}) AS stddev_samp,
+                        AVG({field}) AS average
+                    FROM {table};
+                    """.format(field=col.name, table=imported.name)
+                c.execute(sql)
+                result = c.fetchone()
+                
+                col.count_notnull = result[0]
+                col.count_null = result[1]
+                col.min = result[2]
+                col.max = result[3]
+                col.stddev_pop = result[4]
+                col.stddev_samp = result[5]
+                col.mean = result[6]
+            
+            else:
+                # non-numeric types can do null/not-null.
+                # technically they can and probably should also do frequency
+                # distributions, but those are extra tough to scrape from
+                # the HCUP reference docs
+                sql = """
+                    SELECT
+                        SUM(CASE WHEN {field} IS NULL THEN 0 ELSE 1 END) AS count_notnull,
+                        SUM(CASE WHEN {field} IS NULL THEN 1 ELSE 0 END) AS count_null
+                    FROM {table};
+                    """.format(field=col.name, table=imported.name)
+                c.execute(sql)
+                result = c.fetchone()
+                
+                col.count_notnull = result[0]
+                col.count_null = result[1]
+            
+            col.save()
+            load.log('Recorded Column %s for StagingTable %s' % (col.pk, imported.pk))
         
         """
         else:
@@ -597,14 +644,7 @@ def pg_shovel_ab(self, stg_pk, destination='stg_sid_core_partprocessed'):
     year = rel_file_obj.year
     
      # establish connection directly with psycopg2
-    import psycopg2
-    cnxn = psycopg2.connect(
-        host=DB_DEF['HOST'],
-        port=DB_DEF['PORT'],
-        user=DB_DEF['USER'],
-        password=DB_DEF['PASSWORD'],
-        database=DB_DEF['NAME'],
-        )
+    cnxn = get_pgcnxn()
     
     # generate a cursor
     cursor = cnxn.cursor()
@@ -670,14 +710,7 @@ def pg_stage(self, stagingqueue_pk):
         in_src = stg_input.category
         
         # get a connection and cursor object for use with db.* functions
-        import psycopg2
-        cnxn = psycopg2.connect(
-            host=DB_DEF['HOST'],
-            port=DB_DEF['PORT'],
-            user=DB_DEF['USER'],
-            password=DB_DEF['PASSWORD'],
-            database=DB_DEF['NAME'],
-            )
+        cnxn = get_pgcnxn()
         cursor = cnxn.cursor()
         
         # set aside info about the related ImportQueue object
@@ -906,7 +939,7 @@ def pg_stage(self, stagingqueue_pk):
                 select_items.append('tbl_dte_source.visitlink AS visitlink')
                 jsql += """
                 LEFT JOIN {tbl_dte_source} AS tbl_dte_source
-                ON tbl_dte_source.key = tbl_core_source.key
+                ON tbl_core_source.key = tbl_dte_source.key
                 """.format(tbl_dte_source=tbl_dte_source)
 
             # join in the ahal_cols as well
@@ -917,7 +950,7 @@ def pg_stage(self, stagingqueue_pk):
                     
                 jsql += """
                 LEFT JOIN {tbl_ahal_source} AS tbl_ahal_source
-                ON tbl_ahal_source.key = tbl_core_source.key
+                ON tbl_core_source.dshospid = tbl_ahal_source.dshospid 
                 """.format(tbl_ahal_source=tbl_ahal_source)
 
             # specifically select in columns from tbl_uflags that match names
@@ -930,7 +963,7 @@ def pg_stage(self, stagingqueue_pk):
                 jsql += """
                 LEFT JOIN {tbl_uflags} AS tbl_{flag_name}
                 ON tbl_{flag_name}.name = '{flag_name}' AND
-                    tbl_{flag_name}.key = tbl_core_source.key
+                    tbl_core_source.key = tbl_{flag_name}.key
                 """.format(tbl_uflags=tbl_uflags, flag_name=f, tbl_core_source=tbl_core_source)
             
             # concat everything into a stonking huge SQL statement
