@@ -18,11 +18,12 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.db import connections as cnxns
 from django.db import transaction as tx
+from django.db.models import Q
 
 
 # local project and app packages
 import djhcup_staging
-from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable
+from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable, StagingBatch
 from djhcup_staging.utils.misc import dead_batches
 
 
@@ -49,7 +50,7 @@ def index(request):
          'href': reverse('source_inventory'),
          },
         {'display': 'Batches',
-         'href': reverse('batch_inventory'),
+         'href': reverse('importbatch_inventory'),
          },
         ]
 
@@ -418,8 +419,116 @@ def src_gen_master_table(request, source_id):
     return render(request, template, context)
 
 
-def batch_inventory(request):
+def create_batch_from_unimported(request):
+    now = datetime.datetime.utcnow().strftime("%Y%m%d%H%M%S")
+
+    name = 'Non-imported {now}' \
+        .format(now=now)
+
+    description = 'Non-imported files as of {now}' \
+        .format(now=now)
+
+    b = ImportBatch(name=name, description=description)
+    b.save()
+
+    fqs = File.objects.filter(
+        Q(file_type__content_type='CONTENTWH')|Q(file_type__content_type='CONTENTNH',loadfile__isnull=False)
+        ).exclude(state__abbreviation='TX') # these are special
+
+    fqs = fqs.order_by('state__abbreviation', 'year', '-file_type__compression')
+
+    # add each if one matching state-year is not already in there
+    for f in fqs:
+        # look for other matches that cover this already
+        st = f.state
+        yr = f.year
+        ds = f.file_type.source
+        
+        # either in the database
+        st_tbl_qs = StagingTable.objects.filter(
+            imported_via__file__state=st,
+            imported_via__file__year=yr,
+            imported_via__file__file_type__source=ds
+        )
+        
+        
+        # or in the queue set itself
+        q_qs = File.objects.filter(
+            state=st,
+            year=yr,
+            file_type__source=ds,
+            importqueue__batch=b
+        )
+        
+        if len(st_tbl_qs) == 0 and len(q_qs) == 0:
+            b.importqueue_set.create(file=f)
+    
+    message = 'Created ImportBatch {pk} with {length} files'.format(pk=b.pk, length=len(b.importqueue_set.all()))
+    
+    return importbatch_inventory(request, msg_pass_through=[message])
+
+
+def create_batch_from_unprocessed_t1(request):
+    messages = []
+    
+    now = datetime.datetime.utcnow().strftime("%Y%m%d%H%M%S")
+
+    conversions = [
+        dict(cat_in='CHARGES_SOURCE', cat_out='CHARGES'),
+        dict(cat_in='CORE_SOURCE', cat_out='PR'),
+        dict(cat_in='CORE_SOURCE', cat_out='DX'),
+    ]
+
+    for con in conversions:
+        cat_in = con['cat_in']
+        cat_out = con['cat_out']
+        name = '{cat_in} to {cat_out} {now}' \
+            .format(cat_in=cat_in, cat_out=cat_out, now=now)
+        description = 'Batch of all incomplete {cat_in} to {cat_out} StagingTables as of {now}.' \
+            .format(cat_in=cat_in, cat_out=cat_out, now=now)
+        b = StagingBatch(name=name, description=description)
+        b.save()
+        
+        src_qs = StagingTable.objects.filter(
+            category=con['cat_in'],
+            )
+
+        # add each if one matching state-year is not already in there
+        for t in src_qs:
+            # look for other matches that cover this already
+            f = t.imported_via.file
+            st = f.state
+            yr = f.year
+            
+            # either in the database
+            st_tbl_qs = StagingTable.objects.filter(
+                parent__imported_via__file__state=st,
+                parent__imported_via__file__year=yr,
+                category=con['cat_out'],
+            )
+            
+            # or in the queue set itself
+            q_qs = StagingQueue.objects.filter(
+                stg_input__parent__imported_via_file__state=st,
+                stg_input__parent__imported_via_file__year=yr,
+                category=con['cat_out']
+            )
+            
+            if len(st_tbl_qs) == 0 and len(q_qs) == 0:
+                b.stagingqueue_set.create(
+                    stg_input=t,
+                    category=con['cat_out'],
+                )
+    
+        messages.append('Created StagingBatch {pk} with {length} files'.format(pk=b.pk, length=len(b.stagingqueue_set.all())))
+    
+    return importbatch_inventory(request, msg_pass_through=messages)
+
+
+def importbatch_inventory(request, msg_pass_through=[]):
     logger.debug('Batch inventory requested')
+    messages = []
+    
     batches = ImportBatch.objects.all()
     completed = batches.filter(complete__isnull=False)
     not_started = batches.filter(start__isnull=True)
@@ -442,12 +551,13 @@ def batch_inventory(request):
         'not_started': not_started,
         'started': started,
         'completed': completed,
+        'messages': messages + msg_pass_through
         }
     template = 'djhcup_staging_batch_inventory.html' # automagically looks in the templates directory for this app
     return render(request, template, context)
 
 
-def batch_detail(request, batch_id):
+def importbatch_detail(request, batch_id):
     logger.debug('Batch %s detail requested' % batch_id)
     batch = ImportBatch.objects.get(pk=batch_id)
     enqueued_files = ImportQueue.objects.filter(batch=batch)
@@ -523,37 +633,3 @@ def batch_reset_dead(request):
         }
     template = 'djhcup_staging_base.html'
     return render(request, template, context)
-
-
-def shovel_all_core_source(request):
-    """Shovels all the core shit into a partprocessed table for now"""
-    # TODO: redo this entirely
-    logger.info('shovel_all import requested')
-    print "wtf mates"
-    
-    # import celery for group jobbing
-    import celery
-    logger.info('imported celery')
-    
-    # import tasks for this module
-    from djhcup_staging.tasks import pg_shovel_ab
-    logger.info('imported pg_shovel_ab task')
-    
-    core_st_qs = StagingTable.objects.filter(category='CORE_SOURCE')
-    logger.info('pulled core_st_qs with %s results' % len(core_st_qs))
-    
-    job = celery.group(
-        pg_shovel_ab.si(stg.pk) for stg in core_st_qs
-        )
-    result = job()
-    logger.info('triggered job with these results so far: %s' % result)
-    
-    response = "Group job has been dispatched to Celery"
-    logger.info(response)
-    
-    context = {
-        #'title': 'Import Batch',
-        #'response_messages': [{'content': response, 'type': 'info'}],
-        }
-    template = 'djhcup_staging_base.html'
-    return render(request, template, context)
\ No newline at end of file
